{% include '_header.jinja' %}

from __future__ import annotations
{% if has_datetime or has_date or has_time %}
import datetime
{% endif %}
from typing import Any

from pydantic import BaseModel, ConfigDict, Field
{% if has_enums %}

from .enums import *
{% endif %}


{% for schema in schemas %}
{{ schema }}


{% endfor %}
