"""
django_cfg.apps.integrations.grpc

gRPC integration for django-cfg with Django ORM, JWT auth, monitoring, and admin interface.
"""

default_app_config = 'django_cfg.apps.integrations.grpc.apps.GRPCAppConfig'

__version__ = '1.0.0'
