# Generated by Django 5.2.9 on 2025-12-31 11:42

import django_cfg.apps.integrations.grpc.models.grpc_api_key
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("grpc", "0010_grpcapikey_hash_security"),
    ]

    operations = [
        migrations.AlterField(
            model_name="grpcapikey",
            name="key",
            field=models.CharField(
                blank=True,
                db_index=True,
                default=django_cfg.apps.integrations.grpc.models.grpc_api_key.generate_api_key,
                help_text="DEPRECATED: Use key_hash instead",
                max_length=64,
                null=True,
                unique=True,
            ),
        ),
    ]
