{% include '_header.jinja' %}

from __future__ import annotations
{% if has_datetime or has_date or has_time %}
import datetime
{% endif %}
from typing import Any

from pydantic import BaseModel, ConfigDict, Field
{% if has_enums and enum_names %}
{% if enum_names | length > 3 %}

from ..enums import (
{% for enum_name in enum_names %}
    {{ enum_name }},
{% endfor %}
)
{% else %}

from ..enums import {{ enum_names | join(', ') }}
{% endif %}
{% endif %}


{% for schema in schemas %}
{{ schema }}


{% endfor %}
